``bezier``
==========

    Helper for B |eacute| zier Curves, Triangles, and Higher Order Objects

|build| |pypi| |versions| |docs|

.. |eacute| unicode:: U+000E9 .. LATIN SMALL LETTER E WITH ACUTE
   :trim:

License
-------

Apache 2.0 - See `LICENSE`_ for more information.

.. |docs| image:: https://readthedocs.org/projects/bezier/badge/?version=latest
   :target: http://bezier.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. |build| image:: https://circleci.com/gh/dhermes/bezier.svg?style=shield
   :target: https://circleci.com/gh/dhermes/bezier
   :alt: CirleCI Build
.. |pypi| image:: https://img.shields.io/pypi/v/bezier.svg
   :target: https://pypi.python.org/pypi/bezier
.. |versions| image:: https://img.shields.io/pypi/pyversions/bezier.svg
   :target: https://pypi.python.org/pypi/bezier
